import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';

// ignore: must_be_immutable
class HxButton extends StatelessWidget {
  final String? title;
  final double? width;
  bool disabled = false;
  final bool isLoading;
  final void Function()? onTap;
  final IconData? prefixIcon;
  final IconData? sufixIcon;
  final double? fontSize;
  final double? iconSize;
  final bool isIconButton;
  final VisualDensity? densidade;

  Color hoverColor = kcSecondaryColor;
  Color? backgroundColor;
  Color? fillColor;

  HxButton.primary({
    super.key,
    required this.title,
    this.isLoading = false,
    this.onTap,
    this.prefixIcon,
    this.fontSize,
    this.iconSize,
    this.densidade,
    this.sufixIcon,
    this.width,
  })  : backgroundColor = kcPrimaryColor,
        fillColor = kcBackgroundColor,
        isIconButton = false;

  HxButton.primaryIcon({
    super.key,
    this.isLoading = false,
    required this.onTap,
    required this.prefixIcon,
    this.fontSize,
    this.iconSize,
    this.densidade,
    this.sufixIcon,
    this.width,
  })  : backgroundColor = kcPrimaryColor,
        fillColor = kcBackgroundColor,
        title = null,
        isIconButton = true;

  HxButton.secondary({
    super.key,
    this.title,
    this.isLoading = false,
    this.onTap,
    this.prefixIcon,
    this.fontSize,
    this.iconSize,
    this.densidade,
    this.sufixIcon,
    this.width,
  })  : backgroundColor = kcTertiaryColor,
        fillColor = kcPrimaryColor,
        isIconButton = false;

  HxButton.secondaryIcon({
    super.key,
    this.isLoading = false,
    required this.onTap,
    required this.prefixIcon,
    this.fontSize,
    this.iconSize,
    this.densidade,
    this.sufixIcon,
    this.width,
  })  : backgroundColor = kcTertiaryColor,
        fillColor = kcBackgroundColor,
        title = null,
        isIconButton = true;

  bool isOnHover = false;

  @override
  Widget build(BuildContext context) {
    if (onTap == null) {
      disabled = true;
    }

    return SizedBox(
      width: width,
      child: ElevatedButton(
        onPressed: !isLoading ? onTap : () {},
        style: ElevatedButton.styleFrom(
          foregroundColor: backgroundColor == kcPrimaryColor ? kcBackgroundColor : kcPrimaryColor,
          visualDensity: isIconButton ? const VisualDensity(horizontal: -4) : densidade,
          backgroundColor: backgroundColor,
          disabledBackgroundColor: kcDisabled,
          disabledForegroundColor: kcDarkGrey,
          shadowColor: kcBackgroundColor,
          elevation: 0,
          padding: EdgeInsets.symmetric(
            vertical: isIconButton
                ? 10
                : densidade == VisualDensity.compact
                    ? 16
                    : 18,
            horizontal: isIconButton
                ? 10
                : densidade == VisualDensity.compact
                    ? 12
                    : 24,
          ),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(8),
          ),
        ),
        child: isLoading
            ? SizedBox(
                height: 26,
                width: 26,
                child: CircularProgressIndicator(
                  color: disabled
                      ? Colors.white
                      : backgroundColor == kcPrimaryColor
                          ? kcBackgroundColor
                          : kcPrimaryColor,
                ),
              )
            : Row(
                mainAxisSize: MainAxisSize.min,
                children: [
                  if (prefixIcon != null)
                    Icon(
                      prefixIcon,
                      color: disabled
                          ? Colors.white
                          : backgroundColor == kcPrimaryColor
                              ? kcBackgroundColor
                              : kcPrimaryColor,
                      size: iconSize ?? (densidade == VisualDensity.compact ? 18 : 22),
                    )
                  else
                    Container(),
                  if (title != null)
                    Row(
                      children: [
                        if (prefixIcon != null)
                          const SizedBox(
                            width: 5,
                          ),
                        const SizedBox(
                          height: 26,
                        ),
                        Text(
                          title!,
                          style: TextStyle(
                            color: disabled
                                ? Colors.white
                                : backgroundColor == kcPrimaryColor
                                    ? kcBackgroundColor
                                    : kcPrimaryColor,
                            fontSize: fontSize ?? (densidade == VisualDensity.compact ? 14 : 16),
                          ),
                        ),
                        if (sufixIcon != null)
                          const SizedBox(
                            width: 5,
                          ),
                      ],
                    )
                  else
                    Container(),
                  if (sufixIcon != null)
                    Icon(
                      sufixIcon,
                      color: disabled
                          ? Colors.white
                          : backgroundColor == kcPrimaryColor
                              ? kcBackgroundColor
                              : kcPrimaryColor,
                      size: iconSize ?? (densidade == VisualDensity.compact ? 18 : 22),
                    )
                  else
                    Container(),
                ],
              ),
      ),
    );
  }
}
