import 'package:flutter/material.dart';
import 'package:hx_components_flutter/hx_components.dart';
import 'package:hx_components_flutter/src/utils/appbar_login_customclipper.dart';
import 'package:hx_components_flutter/src/utils/appbar_menu_customclipper.dart';

class HxCurvedAppBar extends StatelessWidget {
  final bool isLogin;
  final Widget? versionWidget;
  final String? user;
  final String? terminal;

  const HxCurvedAppBar.login({
    super.key,
  })  : isLogin = true,
        versionWidget = null,
        user = null,
        terminal = null;

  const HxCurvedAppBar.menu({
    super.key,
    this.versionWidget,
    required this.user,
    required this.terminal,
  }) : isLogin = false;

  @override
  Widget build(BuildContext context) {
    return AppBar(
      backgroundColor: Colors.transparent,
      elevation: 0,
      flexibleSpace: Stack(
        children: [
          ClipPath(
            clipper: isLogin ? AppBarLoginCustomClipper() : AppBarMenuCustomClipper(),
            child: const HxAnimatedBg(),
          ),
          if (isLogin)
            Positioned(
              top: 40,
              left: 40,
              child: Image.asset(
                'packages/hx_components_flutter/assets/images/logo.png',
                width: 200,
              ),
            )
          else
            Positioned(
              top: 40,
              left: MediaQuery.of(context).size.width / 2 - 137 / 2,
              child: Center(
                child: Column(
                  children: [
                    Image.asset(
                      'packages/hx_components_flutter/assets/images/logo.png',
                      width: 137,
                    ),
                  ],
                ),
              ),
            ),
          if (!isLogin)
            Positioned(
              bottom: 55,
              child: SizedBox(
                width: MediaQuery.of(context).size.width - 10,
                child: Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 18.0),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Row(
                        children: [
                          const Icon(
                            Icons.account_circle,
                            color: Colors.white,
                          ),
                          const SizedBox(width: 4),
                          HxText.heading3(
                            user ?? '',
                            color: Colors.white,
                          ),
                        ],
                      ),
                      HxText(
                        'Terminal ${terminal ?? ''}',
                        color: Colors.white,
                      ),
                    ],
                  ),
                ),
              ),
            )
          else
            const SizedBox.shrink(),
        ],
      ),
    );
  }
}
