import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';

class HxDropdownSearch<T> extends StatelessWidget {
  final String label;
  final String? hint;
  final List<T> items;
  final T? initialSelectedItem;
  final bool? isLoading;
  final Function(T?) onChanged;
  final Future<List<T>> Function(String)? asyncItems;
  final Widget Function(BuildContext, T, bool)? itemBuilder;
  final bool enabled;
  final Widget Function(BuildContext, T?)? dropdownBuilder;
  final Widget Function(BuildContext, String)? emptyBuilder;

  const HxDropdownSearch({
    super.key,
    required this.items,
    required this.onChanged,
    required this.label,
    this.isLoading,
    this.hint,
    this.initialSelectedItem,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
    this.emptyBuilder,
  }) : asyncItems = null;

  HxDropdownSearch.async({
    super.key,
    required this.onChanged,
    required this.label,
    required this.asyncItems,
    this.isLoading,
    this.hint,
    this.initialSelectedItem,
    this.itemBuilder,
    this.enabled = true,
    this.dropdownBuilder,
    this.emptyBuilder,
  }) : items = [];

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        DropdownSearch<T>(
          enabled: enabled,
          asyncItems: asyncItems,
          selectedItem: initialSelectedItem,
          dropdownBuilder: dropdownBuilder,
          popupProps: PopupProps.menu(
            emptyBuilder: emptyBuilder,
            itemBuilder: itemBuilder,
            fit: FlexFit.loose,
            showSearchBox: true,
            searchFieldProps: TextFieldProps(
              style: const TextStyle(fontSize: 16),
              decoration: InputDecoration(
                suffixIcon: const Icon(Icons.search),
                labelStyle: TextStyle(color: kcPrimaryColor),
                border: OutlineInputBorder(
                  borderSide: BorderSide(color: kcPrimaryColor),
                ),
              ),
            ),
          ),
          items: items,
          dropdownDecoratorProps: DropDownDecoratorProps(
            baseStyle: const TextStyle(fontSize: 16),
            dropdownSearchDecoration: InputDecoration(
              labelText: label,
              hintText: hint,
              filled: true,
              fillColor: kcLightGrey,
              isDense: true,
              disabledBorder: const UnderlineInputBorder(
                borderSide: BorderSide(color: kcDarkGrey),
              ),
            ),
          ),
          onChanged: onChanged,
        ),
        if (isLoading ?? false) const LinearProgressIndicator() else const SizedBox(),
      ],
    );
  }
}
