import 'package:flutter/material.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';

// ignore: must_be_immutable
class HxOutlineButton extends StatelessWidget {
  final String? title;
  final double? width;
  bool disabled = false;
  final bool isLoading;
  final void Function()? onTap;
  final IconData? prefixIcon;
  final IconData? sufixIcon;
  final double? fontSize;
  final double? iconSize;
  final bool isIconButton;
  final VisualDensity? densidade;

  Color hoverColor = kcSecondaryColor;
  Color? backgroundColor;
  Color? fillColor;

  HxOutlineButton({
    super.key,
    required this.title,
    this.isLoading = false,
    this.onTap,
    this.prefixIcon,
    this.fontSize = 16,
    this.iconSize = 18,
    this.densidade,
    this.sufixIcon,
    this.width,
  })  : backgroundColor = kcPrimaryColor,
        fillColor = kcBackgroundColor,
        isIconButton = false;

  HxOutlineButton.icon({
    super.key,
    this.isLoading = false,
    required this.onTap,
    required this.prefixIcon,
    this.fontSize = 16,
    this.iconSize = 18,
    this.densidade,
    this.sufixIcon,
    this.width,
  })  : backgroundColor = kcPrimaryColor,
        fillColor = kcBackgroundColor,
        title = null,
        isIconButton = true;

  bool isOnHover = false;

  @override
  Widget build(BuildContext context) {
    if (onTap == null) {
      disabled = true;
    }

    return SizedBox(
      width: width,
      child: OutlinedButton(
        onPressed: !isLoading ? onTap : () {},
        style: OutlinedButton.styleFrom(
          visualDensity: isIconButton ? const VisualDensity(horizontal: -4) : densidade,
          elevation: 0,
          padding: EdgeInsets.symmetric(
            vertical: isIconButton
                ? 10
                : densidade == VisualDensity.compact
                    ? 16
                    : 18,
            horizontal: isIconButton
                ? 10
                : densidade == VisualDensity.compact
                    ? 12
                    : 24,
          ),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(8),
          ),
          side: BorderSide(color: kcPrimaryColor),
        ),
        child: isLoading
            ? SizedBox(
                height: 26,
                width: 26,
                child: CircularProgressIndicator(
                  color: kcPrimaryColor,
                ),
              )
            : Row(
                mainAxisSize: MainAxisSize.min,
                children: [
                  if (prefixIcon != null)
                    Icon(
                      prefixIcon,
                      color: kcPrimaryColor,
                    )
                  else
                    Container(),
                  if (title != null)
                    Row(
                      children: [
                        if (prefixIcon != null)
                          const SizedBox(
                            width: 5,
                          ),
                        const SizedBox(
                          height: 26,
                        ),
                        Text(
                          title!,
                          style: TextStyle(
                            color: kcPrimaryColor,
                            fontSize: densidade == VisualDensity.compact ? 14 : 16,
                          ),
                        ),
                        if (sufixIcon != null)
                          const SizedBox(
                            width: 5,
                          ),
                      ],
                    )
                  else
                    Container(),
                  if (sufixIcon != null)
                    Icon(
                      sufixIcon,
                      color: kcPrimaryColor,
                    )
                  else
                    Container(),
                ],
              ),
      ),
    );
  }
}
