import 'package:flutter/material.dart';
import 'package:flutter_styled_toast/flutter_styled_toast.dart';
import 'package:hx_components_flutter/src/shared/app_colors.dart';
import 'package:hx_components_flutter/src/widgets/hx_text.dart';

// ignore: avoid_classes_with_only_static_members
class HxToast {
  static void sucesso(BuildContext context, String message) {
    HxToast._show(
      context: context,
      message: message,
      color: kcSuccess,
      icon: Icons.check_circle,
    );
  }

  static void erro(BuildContext context, String message) {
    HxToast._show(
      context: context,
      message: message,
      color: kcError,
      icon: Icons.error,
    );
  }

  static void _show({
    required BuildContext context,
    required String message,
    required Color color,
    required IconData icon,
  }) {
    showToastWidget(
      curve: Curves.easeInOut,
      Container(
        width: double.infinity,
        padding: const EdgeInsets.all(16),
        margin: const EdgeInsets.symmetric(horizontal: 24.0),
        decoration: ShapeDecoration(
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(8.0),
          ),
          color: color,
        ),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Icon(
              icon,
              color: Colors.white,
              size: 32,
            ),
            const SizedBox(
              width: 10,
            ),
            Expanded(
              child: HxText.heading4(
                message,
                color: Colors.white,
              ),
            ),
            const SizedBox(
              width: 10,
            ),
            IconButton(
              onPressed: () {
                ToastManager().dismissAll(showAnim: true);
              },
              padding: EdgeInsets.zero,
              icon: const Icon(
                Icons.cancel,
                color: Colors.white,
                size: 23,
              ),
            ),
          ],
        ),
      ),
      context: context,
      isIgnoring: false,
      animation: StyledToastAnimation.slideFromBottom,
      reverseAnimation: StyledToastAnimation.slideToBottom,
      duration: const Duration(seconds: 3),
    );
  }
}
